using Godot;

namespace SessionZeroClient.Screens;

public partial class MainScreenLogic : Control
{
    [Export] private TextureButton HamburgerButton { get; set; }
    
    [Export] private Control RightPanel { get; set; }
    [Export] private Control CenterPanel { get; set; }
    [Export] private Control LeftPanel { get; set; }

    private bool _leftPanelEnabled = true;
    private bool _rightPanelEnabled = false;
    
    public Control CurrentLeftContentControl { get; private set; }
    public Control CurrentCenterContentControl { get; private set; }
    public Control CurrentRightContentControl { get; private set; }


    public override void _Ready()
    {
        SetupSignals();
    }
    
    private void SetupSignals()
    {
        HamburgerButton.Pressed += OnHamburgerButtonPressed;
    }
    
    private void OnHamburgerButtonPressed()
    {
        if (!_leftPanelEnabled) EnableLeftPanel();
        else DisableLeftPanel();
    }

    public void DisableLeftPanel()
    {
        LeftPanel.CustomMinimumSize = new(0,0);
        _leftPanelEnabled = false;
    }
    
    public void EnableLeftPanel()
    {
        LeftPanel.CustomMinimumSize = new(200,0);
        _leftPanelEnabled = true;
    }
    
    public void DisableRightPanel()
    {
        LeftPanel.CustomMinimumSize = new(0,0);
        _rightPanelEnabled = false;
    }
    
    public void EnableRightPanel()
    {
        LeftPanel.CustomMinimumSize = new(200,0);
        _rightPanelEnabled = true;
    }
    
    public void ChangeLeftContent(Control contentControl)
    {
        CurrentLeftContentControl = contentControl;
        
        if (LeftPanel.GetChildCount() > 0)
        {
            LeftPanel.RemoveChild(LeftPanel.GetChild(0));
        }
        
        LeftPanel.AddChild(contentControl);
    }
    
    public void ChangeCenterContent(Control contentControl)
    {
        CurrentCenterContentControl = contentControl;
        
        if (CenterPanel.GetChildCount() > 0)
        {
            CenterPanel.RemoveChild(CenterPanel.GetChild(0));
        }
        
        CenterPanel.AddChild(contentControl);
    }
    
    public void ChangeRightContent(Control contentControl)
    {
        CurrentRightContentControl = contentControl;
        
        if (RightPanel.GetChildCount() > 0)
        {
            RightPanel.RemoveChild(RightPanel.GetChild(0));
        }
        
        RightPanel.AddChild(contentControl);
    }
}